@@ -76,8 +76,10 @@ class CategoriesTreeView(object):
         
         # Enable a context menu
         self.context_menu = self._get_context_menu()
+        self.context_menu.attach_to_widget(self.tree_view, lambda x,y:None)
         
         self.tree_view.connect('button-press-event', self.on_button_press_event)
+        self.tree_view.connect('key-press-event', self.on_key_press_event)
         
         # Wrap lines
         self.cell.props.wrap_mode = pango.WRAP_WORD
@@ -93,7 +95,7 @@ class CategoriesTreeView(object):
         return self.tree_store.iter_depth(iter) == 0
         
         
-    def on_editing_started(self, cell, editable, path):     
+    def on_editing_started(self, cell, editable, path):
         # Let the renderer use text not markup temporarily
         self.tvcolumn.clear_attributes(self.cell)
         self.tvcolumn.add_attribute(self.cell, 'text', 0)
@@ -165,8 +167,13 @@ class CategoriesTreeView(object):
 
     
     def add_element(self, parent, element_content):
-        '''Recursive Method for adding the content'''
-        for key, value in element_content.iteritems():
+        '''
+        Recursive Method for adding the content
+        '''
+        # We want to order the entries ascendingly
+        ascending = lambda (key, value): key.lower()
+        
+        for key, value in sorted(element_content.iteritems(), key=ascending):
             if key is not None:
                 key_pango = markup.convert_to_pango(key)
             new_child = self.tree_store.append(parent, [key_pango])
@@ -175,7 +182,12 @@ class CategoriesTreeView(object):
             
         
     def set_day_content(self, day):
-        for key, value in day.content.iteritems():
+        # We want to order the categories ascendingly, having Tags first
+        ascending = lambda x: '000' if x.lower() == 'tags' else x.lower()
+        sorted_keys = sorted(day.content.keys(), key=ascending)
+        
+        for key in sorted_keys:
+            value = day.content[key]
             if not key == 'text':
                 self.add_element(None, {key: value})
         self.tree_view.expand_all()
@@ -384,6 +396,22 @@ class CategoriesTreeView(object):
                 self.delete_node(selected_iter)
                 
                 
+    def on_key_press_event(self, widget, event):
+        """
+        @param widget - gtk.TreeView - The Tree View
+        @param event - gtk.gdk.event - Event information
+        
+        Delete an annotation node when user hits "Delete"
+        """
+        keyname = gtk.gdk.keyval_name(event.keyval)
+        logging.info('Pressed key: %s' % keyname)
+        
+        if keyname == 'Delete':
+            self._on_delete_entry_clicked(None)
+        elif keyname == 'Menu':
+            # Does not work
+            logging.info('Context Menu does not work')
+            self.context_menu.popup(None, None, None, 0, event.time)
                 
                 
     def on_button_press_event(self, widget, event):
@@ -410,6 +438,7 @@ class CategoriesTreeView(object):
         if (event.button == 3):
             #This is a right-click
             self.context_menu.popup(None, None, None, event.button, event.time)
+                        
             
     def _get_context_menu(self):
         context_menu_xml = '''
@@ -458,7 +487,6 @@ class CategoriesTreeView(object):
         iter = self.get_selected_node()
         self.tree_view.set_cursor(self.tree_store.get_path(iter), \
                                 focus_column=self.tvcolumn, start_editing=True)
-        self.tree_view.grab_focus()
     
     def _on_add_entry_clicked(self, action):
         iter = self.get_selected_node()
@@ -478,6 +506,7 @@ class CategoriesTreeView(object):
             category = self.get_iter_value(parent_iter)
             dialog.show_dialog(category=category)
             
+            
     def _on_delete_entry_clicked(self, action):
         self.delete_selected_node()
         
