@@ -25,6 +25,7 @@ import urllib
 import urlparse
 import webbrowser
 import logging
+from xml.sax.saxutils import escape
 
 import gtk
 import gobject
@@ -41,7 +42,6 @@ except ImportError:
 #gobject.threads_init()
 
 from rednotebook.util import utils
-import rednotebook.util.unicode
 
 from rednotebook.gui.menu import MainMenuBar
 from rednotebook.external.htmltextview import HtmlWindow
@@ -97,6 +97,8 @@ class MainWindow(object):
         self.main_frame.set_icon_list(*map(lambda file: gtk.gdk.pixbuf_new_from_file(file), \
                                 filesystem.get_icons()))
         
+        self.is_fullscreen = False
+        
         self.uimanager = gtk.UIManager()
         
         self.menubar_manager = MainMenuBar(self)
@@ -131,7 +133,7 @@ class MainWindow(object):
         
         # Only add the config variable if webkit is available
         # Use webkit by default if it is available
-        self.use_webkit = browser.webkit# and self.journal.config.read('useWebkit', 1)
+        self.use_webkit = bool(browser.webkit)# and self.journal.config.read('useWebkit', 1)
         
         logging.info('Using webkit for previews: %s' % self.use_webkit)
         
@@ -147,16 +149,16 @@ class MainWindow(object):
         self.preview_mode = False
         self.preview_button = self.builder.get_object('preview_button')
         
-        # Let the preview button always have the same size        
-        preview_button = self.preview_button
-        preview_button.realize()
-        width_edit = get_button_width(preview_button, _('Edit'))
-        width_preview = get_button_width(preview_button, _('Preview'))
-        preview_button.set_size_request(max([width_edit, width_preview]), -1)
-        
+        # Let the edit_paned respect its childs size requests
+        edit_paned = self.builder.get_object('edit_pane')
+        text_vbox = self.builder.get_object('text_vbox')
+        edit_paned.child_set_property(text_vbox, 'shrink', False)
         
         self.load_values_from_config()
         
+        if not sys.platform == 'win32':
+            self.main_frame.set_position(gtk.WIN_POS_CENTER)
+        
         if not self.journal.start_minimized:
             self.main_frame.show()
         
@@ -175,6 +177,7 @@ class MainWindow(object):
             #'on_calendar_day_selected': self.on_calendar_day_selected,
             
             'on_preview_button_clicked': self.on_preview_button_clicked,
+            'on_edit_button_clicked': self.on_edit_button_clicked,
             
             'on_main_frame_configure_event': self.on_main_frame_configure_event,
             'on_main_frame_window_state_event': self.on_main_frame_window_state_event,
@@ -374,30 +377,25 @@ class MainWindow(object):
         setattr(self.stats_dialog, 'day_list', day_list)
         for list in [overall_list, day_list]:
             list.set_headers_visible(False)
-            
-            
-    def on_preview_button_clicked(self, button):
+        
+        
+    def change_mode(self, preview):
         self.journal.save_old_day()
         
         text_scrolledwindow = self.builder.get_object('text_scrolledwindow')
         template_button = self.builder.get_object('template_menu_button')
         
+        edit_button = self.builder.get_object('edit_button')
+        preview_button = self.builder.get_object('preview_button')
+        
+        size_group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+        size_group.add_widget(edit_button)
+        size_group.add_widget(preview_button)
+        
         # Do not forget to update the text in editor and preview respectively
         
-        if self.preview_mode:
-            # Enter edit mode
-            self.day_text_field.set_text(self.day.text, undoing=True)
-            self.day_text_field.day_text_view.grab_focus()
-            
-            text_scrolledwindow.show()
-            self.html_editor.hide()
-            self.preview_button.set_stock_id('gtk-media-play')
-            ### Translators: Verb
-            self.preview_button.set_label(_('Preview'))
-            
-            self.preview_mode = False
-        else:
-            # Enter preview mode            
+        if preview:
+            # Enter preview mode
             text_scrolledwindow.hide()
             self.html_editor.show()
             day = self.journal.day
@@ -406,15 +404,30 @@ class MainWindow(object):
             
             self.html_editor.load_html(html)
             
-            self.preview_button.set_stock_id('gtk-edit')
-            #self.preview_button.set_label(' '*3 + 'Edit' + ' '*4)
-            self.preview_button.set_label(_('Edit'))
+            edit_button.show()
+            preview_button.hide()
+        else:
+            # Enter edit mode
+            self.day_text_field.set_text(self.day.text, undoing=True)
+            self.day_text_field.day_text_view.grab_focus()
             
-            self.preview_mode = True
+            text_scrolledwindow.show()
+            self.html_editor.hide()
             
-        template_button.set_sensitive(not self.preview_mode)
-        self.single_menu_toolbutton.set_sensitive(not self.preview_mode)
-        self.format_toolbutton.set_sensitive(not self.preview_mode)
+            preview_button.show()
+            edit_button.hide()
+            
+        template_button.set_sensitive(not preview)
+        self.single_menu_toolbutton.set_sensitive(not preview)
+        self.format_toolbutton.set_sensitive(not preview)
+        
+        self.preview_mode = preview
+        
+    def on_edit_button_clicked(self, button):
+        self.change_mode(preview=False)
+        
+    def on_preview_button_clicked(self, button):
+        self.change_mode(preview=True)
         
             
     def setup_search(self):
@@ -491,11 +504,22 @@ class MainWindow(object):
         minimized, maximized, made sticky, made not sticky, shaded or 
         unshaded.   
         '''
-        state = event.new_window_state
-        maximized = state and gtk.gdk.WINDOW_STATE_MAXIMIZED
-        maximized = int(bool(maximized))
-        self.journal.config['mainFrameMaximized'] = maximized
+        if event.changed_mask & gtk.gdk.WINDOW_STATE_MAXIMIZED:
+            maximized = bool(event.new_window_state & gtk.gdk.WINDOW_STATE_MAXIMIZED)
+            self.journal.config['mainFrameMaximized'] = int(maximized)
         
+        # Does not work correctly -> Track fullscreen state in program
+        #self.is_fullscreen = bool(state and gtk.gdk.WINDOW_STATE_FULLSCREEN)
+        
+    def toggle_fullscreen(self):
+        if self.is_fullscreen:
+            self.main_frame.unfullscreen()
+            self.menubar.show()
+            self.is_fullscreen = False
+        else:
+            self.main_frame.fullscreen()
+            self.menubar.hide()
+            self.is_fullscreen = True
         
     def on_back_one_day_button_clicked(self, widget):
         self.journal.go_to_prev_day()
@@ -610,7 +634,7 @@ class MainWindow(object):
         if config.read('mainFrameMaximized', 0):
             self.main_frame.maximize()
         
-        if 'left_divider_position' in config:
+        if 'leftDividerPosition' in config:
             self.builder.get_object('main_pane').set_position(config.read('leftDividerPosition', -1))
         self.builder.get_object('edit_pane').set_position(config.read('rightDividerPosition', 500))
         
@@ -894,9 +918,8 @@ class MainWindow(object):
             base, ext = os.path.splitext(picture_chooser.get_filename())
             
             # On windows firefox accepts absolute filenames only 
-            # with the file:// prefix
-            if not base.startswith('file://'):
-                base = 'file://' + base
+            # with the file:/// prefix
+            base = filesystem.get_local_url(base)
                 
             self.day_text_field.insert('[""%s""%s]' % (base, ext))
             
@@ -911,8 +934,7 @@ class MainWindow(object):
         if response == gtk.RESPONSE_OK:
             dirs.last_file_dir = file_chooser.get_current_folder()
             filename = file_chooser.get_filename()
-            filename = os.path.normpath(filename)
-            filename = 'file://' + filename
+            filename = filesystem.get_local_url(filename)
             head, tail = os.path.split(filename)
             # It is always safer to add the "file://" protocol and the ""s
             self.day_text_field.insert('[%s ""%s""]' % (tail, filename))
@@ -1011,6 +1033,7 @@ class MainWindow(object):
         self.day_text_field.highlight(search_text)
             
 
+
 class NewEntryDialog(object):
     def __init__(self, main_frame):
         dialog = main_frame.builder.get_object('new_entry_dialog')
@@ -1035,9 +1058,9 @@ class NewEntryDialog(object):
         '''Show Tags in ComboBox when "Tags" is selected as category'''
         if self.categories_combo_box.get_active_text().upper() == 'TAGS':
             self.new_entry_combo_box.set_entries(self.journal.tags)
-        else:
-            self.new_entry_combo_box.clear()
-             
+        elif self.new_entry_combo_box.liststore:
+            self.new_entry_combo_box.liststore.clear()
+            
         # only make the entry submittable, if text has been entered
         self.dialog.set_response_sensitive(gtk.RESPONSE_OK, self._text_entered())
         
@@ -1132,6 +1155,7 @@ class SearchComboBox(CustomComboBoxEntry):
         """
         self.search(self.get_active_text())
         
+        
     def on_entry_activated(self, entry):
         """
             Called when the user hits enter
@@ -1146,6 +1170,7 @@ class SearchComboBox(CustomComboBoxEntry):
             
         self.search(self.get_active_text())
             
+            
     def search(self, search_text):
         if self.search_type == 0:
             # Tell the webview which text to highlight after the html is loaded
@@ -1366,8 +1391,12 @@ class SearchTreeView(object):
         if rows:
             for date_string, entry in rows:
                 if self.search_type == 1:
+                    # We want **done** to be bold in the list,
+                    # but the text should only be bold where the search text occurs
                     entry = markup.convert_to_pango(entry)
-                
+                else:
+                    entry = escape(entry)
+                    entry = entry.replace('STARTBOLD', '<b>').replace('ENDBOLD', '</b>')
                 self.tree_store.append([date_string, entry])
                 
                 
@@ -1411,6 +1440,10 @@ class DayTextField(object):
         #self.day_text_view.connect('drag-drop', self.on_drop) # unneeded
         self.day_text_view.connect('drag-data-received', self.on_drag_data_received)
         
+        # Sometimes making the editor window very small causes the program to freeze
+        # So we forbid that behaviour, by setting a minimum width
+        self.day_text_view.set_size_request(1, -1)
+        
     def set_text(self, text, undoing=False):
         self.insert(text, overwrite=True, undoing=undoing)
         
@@ -1443,6 +1476,8 @@ class DayTextField(object):
         
             
     def highlight(self, text):
+        self.day_text_buffer.set_search_text(text)
+        return
         iter_start = self.day_text_buffer.get_start_iter()
         
         # Hack: Ignoring the case is not supported for the search so we search
