@@ -20,6 +20,7 @@
 from __future__ import with_statement
 
 import os
+import sys
 import logging
 
 import pango
@@ -37,28 +38,6 @@ from rednotebook.util import filesystem
 from rednotebook.util import dates
 from rednotebook.util import utils
 
-use_mathjax = False
-
-mathjax_header = '''\
-<script src="/home/jendrik/projects/RedNotebook/journalgeist/rednotebook/external/mathjax/MathJax.js">
-  MathJax.Hub.Config({
-    extensions: ["tex2jax.js","TeX/noErrors.js"],
-    jax: ["input/TeX","output/HTML-CSS"],
-    tex2jax: {inlineMath: [["$","$"],["\\(","\\)"]]}
-  });
-</script>
-'''
-
-mathjax_header = '''\
-<script src="/home/jendrik/projects/RedNotebook/journalgeist/rednotebook/external/mathjax/MathJax.js">
-  MathJax.Hub.Config({
-    extensions: ["tex2jax.js"],
-    jax: ["input/TeX","output/HTML-CSS"],
-    tex2jax: {inlineMath: [["$","$"],["\\(","\\)"]]}
-  });
-</script>
-'''
-
 
 
 def convert_categories_to_markup(categories, with_category_title=True):
@@ -149,10 +128,6 @@ def _get_config(type):
         # Apply image resizing
         config['postproc'].append([r'src=\"WIDTH(\d+)-', r'width="\1" src="'])
         
-        if use_mathjax:
-            # Insert MathJax Header
-            config['postproc'].append(['</head>', mathjax_header + '</head>'])
-        
     elif type == 'tex':
         config['encoding'] = 'utf8'
         config['preproc'].append(['€', 'Euro'])
@@ -163,10 +138,19 @@ def _get_config(type):
         config['preproc'].append([r'\[""', r'["""'])
         config['preproc'].append([r'""\.', r'""".'])
         
+        scheme = 'file:///' if sys.platform == 'win32' else 'file://'
+        
         # For images we have to omit the file:// prefix
-        config['postproc'].append([r'includegraphics\{(.*)"file://', r'includegraphics{"\1'])
+        config['postproc'].append([r'includegraphics\{(.*)"%s' % scheme, r'includegraphics{"\1'])
         #config['postproc'].append([r'includegraphics\{"file://', r'includegraphics{"'])
         
+        # Special handling for LOCAL file links (Omit scheme, add run:)
+        # \htmladdnormallink{file.txt}{file:///home/user/file.txt}
+        # -->
+        # \htmladdnormallink{file.txt}{run:/home/user/file.txt}
+        config['postproc'].append([r'htmladdnormallink\{(.*)\}\{%s(.*)\}' % scheme, 
+                                   r'htmladdnormallink{\1}{run:\2}'])
+        
         # Allow line breaks, r'\\\\' are 2 \ for regexes
         config['postproc'].append([r'\$\\backslash\$\$\\backslash\$', r'\\\\'])
         
@@ -349,10 +333,7 @@ if __name__ == '__main__':
 normal text, normal_text_with_underscores and ""raw_text_with_underscores""
 
 [Link ""http://www.co.whatcom.wa.us/health/environmental/site_hazard/sitehazard.jsp""]
-
-[hs_err_pid13673.log ""file:///home/jendrik/hs_err_pid13673.log""]
-
-[""/home/jendrik/Desktop/desktop pics/bg8_karte_s1_rgb"".jpg]'''
+'''
 
     
     
